package com.link.core.converter.util;

import java.io.PrintStream;
import java.io.PrintWriter;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement
public class ExceptionBean implements Serializable {
   private static final long serialVersionUID = 6737498002060410963L;
   private String exceptionClass;
   private String message;
   private List<StackTraceBean> stackTrace;
   private ExceptionBean cause;

   public String getExceptionClass() {
      return this.exceptionClass;
   }

   public void setExceptionClass(String exceptionClass) {
      this.exceptionClass = exceptionClass;
   }

   public String getMessage() {
      return this.message;
   }

   public void setMessage(String message) {
      this.message = message;
   }

   public List<StackTraceBean> getStackTrace() {
      if (this.stackTrace == null) {
         this.stackTrace = new ArrayList();
      }

      return this.stackTrace;
   }

   public void setStackTrace(List<StackTraceBean> stackTrace) {
      this.stackTrace = stackTrace;
   }

   public ExceptionBean getCause() {
      return this.cause;
   }

   public void setCause(ExceptionBean cause) {
      this.cause = cause;
   }

   public String toString() {
      StringBuffer sb = new StringBuffer();
      sb.append(this.exceptionClass);
      if (this.message != null) {
         sb.append(": ");
         sb.append(this.message);
      }

      return sb.toString();
   }

   public void printStackTrace() {
      this.printStackTrace(System.err);
   }

   public void printStackTrace(PrintStream s) {
      synchronized(s) {
         s.println(this.toString());
         Iterator var3 = this.stackTrace.iterator();

         while(var3.hasNext()) {
            StackTraceBean traceBean = (StackTraceBean)var3.next();
            s.println("\tat " + traceBean.toString());
         }

         if (this.cause != null) {
            this.cause.printStackTraceAsCause(s, this.stackTrace);
         }

      }
   }

   public void printStackTrace(PrintWriter s) {
      synchronized(s) {
         s.println(this.toString());
         Iterator var3 = this.stackTrace.iterator();

         while(var3.hasNext()) {
            StackTraceBean traceBean = (StackTraceBean)var3.next();
            s.println("\tat " + traceBean.toString());
         }

         if (this.cause != null) {
            this.cause.printStackTraceAsCause(s);
         }

      }
   }

   public ExceptionBean clone() {
      ExceptionBean other = new ExceptionBean();
      other.exceptionClass = this.exceptionClass;
      other.message = this.message;
      if (this.stackTrace != null && !this.stackTrace.isEmpty()) {
         other.stackTrace = new ArrayList();
         Iterator var2 = this.stackTrace.iterator();

         while(var2.hasNext()) {
            StackTraceBean stackTraceBean = (StackTraceBean)var2.next();
            other.stackTrace.add(stackTraceBean.clone());
         }
      }

      other.cause = this.cause == null ? null : this.cause.clone();
      return other;
   }

   private void printStackTraceAsCause(PrintStream s, List<StackTraceBean> causedTraces) {
      assert s != null;

      assert causedTraces != null;

      s.println("Caused by: " + this.toString());
      int finishIndex = this.stackTrace.size() - causedTraces.size() - 1;

      for(int index = 0; index <= finishIndex; ++index) {
         StackTraceBean traceBean = (StackTraceBean)this.stackTrace.get(index);
         s.println("\tat " + traceBean.toString());
      }

      if (causedTraces.size() > 0) {
         s.println("\t... " + causedTraces.size() + " more");
      }

      if (this.cause != null) {
         this.cause.printStackTraceAsCause(s, this.stackTrace);
      }

   }

   private void printStackTraceAsCause(PrintWriter s) {
      s.println("Caused by: " + this.toString());
      Iterator var2 = this.stackTrace.iterator();

      while(var2.hasNext()) {
         StackTraceBean traceBean = (StackTraceBean)var2.next();
         s.println("\tat " + traceBean.toString());
      }

      if (this.cause != null) {
         this.cause.printStackTraceAsCause(s);
      }

   }
}
